@@ -147,7 +147,11 @@ public:
     Frame*                 m_nextMCSTF;           // PicList doubly linked list pointers
     Frame*                 m_prevMCSTF;
     int*                   m_isSubSampled;
+    TemporalFilterRefPicInfo m_mcstfRefList[MAX_MCSTF_TEMPORAL_WINDOW_LENGTH];
+    PicYuv*                m_mcstffencPic;
 
+    /*Vbv-End-Flag*/
+    int vbvEndFlag;
     /* aq-mode 4 : Gaussian, edge and theta frames for edge information */
     pixel*                 m_edgePic;
     pixel*                 m_gaussianPic;
@@ -171,6 +175,13 @@ public:
     Frame*                 m_nextSubDPB;           // PicList doubly linked list pointers
     Frame*                 m_prevSubDPB;
 
+    /*Target bitrate for this picture*/
+    int64_t                m_targetBitrate;
+    /* target CRF for this picture.*/
+    double                 m_targetCrf;
+    /* target QP for this picture.*/
+    int                    m_targetQp;
+
     Frame();
 
     bool create(x265_param *param, float* quantOffsets);
