@@ -60,33 +60,6 @@ LevelSpec levels[] =
     { MAX_UINT, MAX_UINT, MAX_UINT, MAX_UINT, MAX_UINT, MAX_UINT, 1, Level::LEVEL8_5, "8.5", 85 },
 };
 
-#if ENABLE_SCC_EXT
-enum SCCProfileName
-{
-    NONE = 0,
-    // The following are SCC profiles, which would map to the MAINSCC profile idc.
-    // The enumeration indicates the bit-depth constraint in the bottom 2 digits
-    //                           the chroma format in the next digit
-    //                           the intra constraint in the next digit
-    //                           If it is a SCC profile there is a '2' for the next digit.
-    //                           If it is a highthroughput , there is a '2' for the top digit else '1' for the top digit
-    SCC_MAIN = 121108,
-    SCC_MAIN_10 = 121110,
-    SCC_MAIN_444 = 121308,
-    SCC_MAIN_444_10 = 121310,
-};
-
-static const SCCProfileName validSCCProfileNames[1][4/* bit depth constraint 8=0, 10=1, 12=2, 14=3*/][4/*chroma format*/] =
-{
-   {
-        { NONE,         SCC_MAIN,      NONE,      SCC_MAIN_444                     }, // 8-bit  intra for 400, 420, 422 and 444
-        { NONE,         SCC_MAIN_10,   NONE,      SCC_MAIN_444_10                  }, // 10-bit intra for 400, 420, 422 and 444
-        { NONE,         NONE,          NONE,      NONE                             }, // 12-bit intra for 400, 420, 422 and 444
-        { NONE,         NONE,          NONE,      NONE                             }  // 16-bit intra for 400, 420, 422 and 444
-    },
-};
-#endif
-
 static inline int _confirm(x265_param* param, bool bflag, const char* message)
 {
     if (!bflag)
@@ -282,24 +255,6 @@ void determineLevel(const x265_param &param, VPS& vps)
         break;
     }
 
-#if ENABLE_SCC_EXT
-    x265_param m_param = param;
-#define CHECK(expr, msg) check_failed |= _confirm(&m_param, expr, msg)
-    int check_failed = 0; /* abort if there is a fatal configuration problem */
-
-    if (vps.ptl.profileIdc[0] == Profile::MAINSCC)
-    {
-        CHECK(vps.ptl.lowerBitRateConstraintFlag == false && vps.ptl.intraConstraintFlag == false, "The lowerBitRateConstraint flag cannot be false when intraConstraintFlag is false");
-        CHECK(param.bEnableSCC && !(vps.ptl.profileIdc[0] == Profile::MAINSCC), "UseIntraBlockCopy must not be enabled unless the SCC profile is being used.");
-        CHECK(vps.ptl.intraConstraintFlag, "intra constraint flag must be 0 for SCC profiles");
-        CHECK(vps.ptl.onePictureOnlyConstraintFlag, "one-picture-only constraint flag shall be 0 for SCC profiles");
-        const uint32_t bitDepthIdx = (vps.ptl.bitDepthConstraint == 8 ? 0 : (vps.ptl.bitDepthConstraint == 10 ? 1 : (vps.ptl.bitDepthConstraint == 12 ? 2 : (vps.ptl.bitDepthConstraint == 16 ? 3 : 4))));
-        const uint32_t chromaFormatIdx = uint32_t(vps.ptl.chromaFormatConstraint);
-        const bool bValidProfile = (bitDepthIdx > 2 || chromaFormatIdx > 3) ? false : (validSCCProfileNames[0][bitDepthIdx][chromaFormatIdx] != NONE);
-        CHECK(!bValidProfile, "Invalid intra constraint flag, bit depth constraint flag and chroma format constraint flag combination for a RExt profile");
-    }
-#endif
-
     static const char* profiles[] = { "None", "Main", "Main 10", "Main Still Picture", "RExt", "", "", "", "", "Main Scc" };
     static const char *tiers[]    = { "Main", "High" };
 
